# Xplt

A plotting library for [Xsuite](https://github.com/xsuite) and simmilar accelerator physics codes.


## Usage

```bash
pip install xplt
```

Read the docs at https://eltos.github.io/xplt



## Developer installation

```bash
git clone git@github.com:eltos/xplt.git
cd xplt
pip install -e .
pip install pre-commit
pre-commit install
git config core.autocrlf input
```
